"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _chalk = _interopRequireDefault(require("chalk"));

var _detectPortAlt = _interopRequireDefault(require("detect-port-alt"));

var _inquirer = _interopRequireDefault(require("inquirer"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function clearConsole() {
  process.stdout.write(process.platform === 'win32' ? '\x1B[2J\x1B[0f' : '\x1B[2J\x1B[3J\x1B[H');
}

var choosePort = function choosePort(host, defaultPort) {
  return (0, _detectPortAlt["default"])(defaultPort, host).then(function (port) {
    return new Promise(function (resolve) {
      if (port === defaultPort) {
        return resolve(port);
      }

      var message = // process.platform !== 'win32' && defaultPort < 1024 && !isRoot()
      process.platform !== 'win32' && defaultPort < 1024 ? "Admin permissions are required to run a server on a port below 1024." : "Something is already running on port ".concat(defaultPort, ".");

      if (process.stdout.isTTY) {
        clearConsole();
        var question = {
          type: 'confirm',
          name: 'shouldChangePort',
          message: _chalk["default"].yellow(message) + '\n\nWould you like to run the app on another port instead?',
          "default": true
        };

        _inquirer["default"].prompt(question).then(function (answer) {
          if (answer.shouldChangePort) {
            resolve(port);
          } else {
            resolve();
          }
        });
      } else {
        console.log(_chalk["default"].red(message));
        resolve();
      }
    });
  }, function (err) {
    throw new Error(_chalk["default"].red("Could not find an open port at ".concat(_chalk["default"].bold(host), ".")) + '\n' + ('Network error message: ' + err.message || err) + '\n');
  });
};

var _default = choosePort;
exports["default"] = _default;
module.exports = exports.default;